OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "Rekommenderade filer",
    "No recommendations yet" : "Inga rekommendationer än",
    "Recently commented" : "Nyligen kommenterade",
    "Recently edited" : "Nyligen redigerad",
    "Recently shared" : "Nyligen delade",
    "Recommendations" : "Rekommendationer",
    "Shows recommended files" : "Visar rekommenderade filer",
    "Shows recommended files for quick access of files and folders with recent activity" : "Visar rekommenderade filer för snabb åtkomst av filer och mappar med senast aktivitet",
    "Path name {path}" : "Sökvägsnamn {path}",
    "Show recommendations" : "Visa rekommendationer"
},
"nplurals=2; plural=(n != 1);");
